@@ -73,7 +73,7 @@ def random_gear(cr, identify=False):
 
 class Potion:
     random_potion = FlexCat({
-        1: (
+        "1": (
             "Potion case: 10 Potions of healing",
             "Potion of animal friendship",
             "Potion of water breathing",
@@ -87,7 +87,7 @@ class Potion:
             "Potion of diminution",
             "Potion of gaseous form",
         ),
-        2: (
+        "2": (
             "Potion case: 10 Potions of greater healing",
             "Potion of frost giant strength",
             "Potion of fire giant strength",
@@ -97,13 +97,13 @@ class Potion:
             "Potion of invisibility",
             "Potion of resistance",
         ),
-        3: (
+        "3": (
             "Potion case: 10 Potions of superior healing",
             "Potion of stone giant strength",
             "Potion of mind reading",
             "Potion of heroism",
         ),
-        4: (
+        "4": (
             "Potion case: 10 Potions of supreme healing",
             "Potion of storm giant strength",
             "Potion of longevity",
@@ -113,7 +113,7 @@ class Potion:
 
     def __init__(self, cr):
         tier = d(CR(cr).tier)
-        self.name = self.random_potion(tier)
+        self.name = self.random_potion(str(tier))
         self.price = f"{dice(5, 100)} {('Silver', 'Electrum', 'Gold', 'Platinum')[tier - 1]}"
 
     def __repr__(self):
@@ -123,5 +123,5 @@ class Potion:
 if __name__ == '__main__':
     print()
     for _ in range(10):
-        p = BasicGear(5)
-        print(f"{p}, {p.id}")
+        p = Potion(1)
+        print(f"{p}")
