@@ -15,7 +15,7 @@ class Trap:
     rank_2_damage = "3d6"
     rank_3_damage = "4d8"
     rank_4_damage = "5d10"
-    random_ability = TruffleShuffle(("CON", "STR", "DEX", "CHA", "INT", "WIS"))
+    random_ability = TruffleShuffle(("CON", "STR", "DEX", "INT", "WIS"))
     random_trap = FlexCat({
         'bludgeoning': ("Falling Rocks", "Swinging Hammer", "Falling Chandelier"),
         'falling': ("Deep Pit", "Spring Loaded Floor Tile", "Greased Slide", "False Floor"),
